@@ -1,6 +1,6 @@
 import dataclasses
 import os
-from functools import wraps
+from functools import cached_property, wraps
 from typing import List, Optional, Sequence, Set
 
 from ens import ENS
@@ -14,6 +14,7 @@ from web3 import Web3
 from web3.exceptions import BadFunctionCallOutput
 
 from gnosis.eth import EthereumClient, EthereumNetwork, TxSpeed
+from gnosis.eth.clients import EtherscanClient, EtherscanClientConfigurationProblem
 from gnosis.eth.constants import NULL_ADDRESS, SENTINEL_ADDRESS
 from gnosis.eth.contracts import (
     get_erc20_contract,
@@ -24,18 +25,12 @@ from gnosis.eth.contracts import (
 from gnosis.safe import InvalidInternalTx, Safe, SafeOperation, SafeTx
 from gnosis.safe.multi_send import MultiSend, MultiSendOperation, MultiSendTx
 
-from safe_cli.api.etherscan_api import EtherscanApi
 from safe_cli.api.relay_service_api import RelayServiceApi
 from safe_cli.api.transaction_service_api import TransactionServiceApi
 from safe_cli.ethereum_hd_wallet import get_account_from_words
 from safe_cli.safe_addresses import LAST_DEFAULT_CALLBACK_HANDLER, LAST_SAFE_CONTRACT
 from safe_cli.utils import get_erc_20_list, yes_or_no_question
 
-try:
-    from functools import cached_property
-except ImportError:
-    from cached_property import cached_property
-
 
 @dataclasses.dataclass
 class SafeCliInfo:
@@ -183,7 +178,10 @@ class SafeOperator:
         self.ethereum_client = EthereumClient(self.node_url)
         self.ens = ENS.fromWeb3(self.ethereum_client.w3)
         self.network: EthereumNetwork = self.ethereum_client.get_network()
-        self.etherscan = EtherscanApi.from_ethereum_client(self.ethereum_client)
+        try:
+            self.etherscan = EtherscanClient(self.network)
+        except EtherscanClientConfigurationProblem:
+            self.etherscan = None
         self.safe_relay_service = RelayServiceApi.from_ethereum_client(
             self.ethereum_client
         )
